@@ -4,7 +4,7 @@ from bottle import request, abort
 from injector import inject, Injector
 from pyckson import serialize
 
-from antibot.internal.backend.constants import WS_JSON_VALUES
+from antibot.internal.backend.constants import WS_JSON_VALUES, NO_AUTH
 from antibot.internal.backend.debugger import Debugger
 from antibot.internal.configuration import Configuration
 from antibot.plugin import AntibotPlugin
@@ -19,7 +19,7 @@ class WsRunner:
 
     def run_ws(self, method, plugin: Type[AntibotPlugin], **kwargs):
         request_key = request.params.get('apikey') or request.headers.get('X-Gitlab-Token')
-        if self.configuration.ws_api_key != request_key:
+        if not getattr(method, NO_AUTH, False) and self.configuration.ws_api_key != request_key:
             abort(401, 'Could not verify api key')
         ip = request.get_header('X-Forwarded-For', request.environ.get('REMOTE_ADDR'))
         instance = self.injector.get(plugin)
